@@ -42,12 +42,12 @@
 
 
 # Create a class object ComDim.
-ComDim <- function(X, block, name.block, ncomp=NULL, scale=TRUE, scale.block=TRUE, threshold=1e-8){
+ComDim <- function(X, block, name.block=NULL, ncomp=NULL, scale=TRUE, scale.block=TRUE, threshold=1e-8){
   # ---------------------------------------------------------------------------
   # 0. Preliminary tests
   # ---------------------------------------------------------------------------
 
-  if (any(is.na(X))){   # to be modified if missing values allowed
+  if (anyNA(X)){   # to be modified if missing values allowed
     stop("No NA values are allowed")
   }
   if (sum(block) != ncol(X)){
@@ -135,7 +135,7 @@ ComDim <- function(X, block, name.block, ncomp=NULL, scale=TRUE, scale.block=TRU
   # 2. Required parameters and data preparation
   # ---------------------------------------------------------------------------
   Xinput        <- X
-  Xscale$mean   <- apply(X, 2, mean)
+  Xscale$mean   <- colMeans(X)
   X             <-sweep(X, 2, Xscale$mean, "-")              # Default centering
 
   if (scale==FALSE) {   # no scaling
@@ -241,7 +241,7 @@ ComDim <- function(X, block, name.block, ncomp=NULL, scale=TRUE, scale.block=TRU
   if (ncomp==1) {
     Scor.g=T.g*sqrt(colSums(LAMBDA))
   }  else {
-    Scor.g=T.g%*%sqrt(diag(colSums(LAMBDA)))
+    Scor.g=T.g%*%diag(sqrt(colSums(LAMBDA)))
   }
   dimnames(Scor.g) <- dimnames(T.g)    # Unnormed global components
 
@@ -250,7 +250,7 @@ ComDim <- function(X, block, name.block, ncomp=NULL, scale=TRUE, scale.block=TRU
   Load.g=t(t(Load.g)/colSums(Scor.g^2))
 
   # Global Projection
-  Proj.g <- W.g %*% solve(crossprod(Load.g,W.g),tol=1e-300)      # Weights that take into account the deflation procedure
+  Proj.g <- W.g %*% solve(crossprod(Load.g,W.g))      # Weights that take into account the deflation procedure
 
 
 
