@@ -24,9 +24,7 @@
 #' @export
 
 plot.ComDim=function(x,axes=c(1,2),size=2.25,...){
-  if (!inherits(x, c("ComDim"))){
-    stop("class(x) must be ComDim")
-  }
+  
   if (is.integer(axes) | is.numeric(axes)){
     if (length(axes)!=2){
       stop("length(axes) must be 2")
